@@ -168,10 +168,10 @@ class Selenium(Scraper):
                 element.click()
             except Exception as e:
                 try:
-                    self.scraper.driver.execute_script("arguments[0].click();", element)
+                    self.driver.execute_script("arguments[0].click();", element)
                 except Exception as e:
                     try:
-                        actions = ActionChains(self.scraper.driver)
+                        actions = ActionChains(self.driver)
                         actions.click(element).perform()
                     except Exception as e:
                         return None
